@@ -7,17 +7,42 @@ use base qw(Exporter);
 	   %known_obsolete_fields %known_essential %known_build_essential
 	   %known_obsolete_packages %known_virtual_packages
 	   %known_libstdcs %known_tcls %known_tclxs %known_tks %known_tkxs
-	   %known_libpngs %non_standard_archs
+	   %known_libpngs %known_x_metapackages
+	   %non_standard_archs %all_cpus %all_oses
+	   %known_doc_base_formats
           );
 
 # simple defines for commonly needed data
 
+# From /usr/share/dpkg/archtable, included here to make lintian results
+# consistent no matter what dpkg one has installed.
 %known_archs = map { $_ => 1 }
-    ('alpha', 'arm', 'hppa', 'hurd-386', 'i386', 'ia64', 'mips', 'mipsel', 
-     'm68k', 'powerpc', 's390', 'sparc', 'any', 'all');
+    ('i386', 'ia64', 'alpha', 'amd64', 'arm', 'hppa', 'm68k', 'mips',
+     'mipsel', 'powerpc', 's390', 'sparc', 'hurd-i386', 'any', 'all');
 
+# From /usr/share/dpkg/cputable, included here to make lintian results
+# consistent no matter what dpkg one has installed.
+%all_cpus = map { $_ => 1 }
+    ('i386', 'ia64', 'alpha', 'amd64', 'armeb', 'arm', 'hppa', 'm32r', 'm68k',
+     'mips', 'mipsel', 'powerpc', 'ppc64', 's390', 's390x', 'sh3', 'sh3eb',
+     'sh4', 'sh4eb', 'sparc');
+
+# From /usr/share/dpkg/ostable, included here to make lintian results
+# consistent no matter what dpkg one has installed.
+%all_oses = map { $_ => 1 }
+    ('linux', 'darwin', 'freebsd', 'kfreebsd', 'knetbsd', 'netbsd', 'openbsd',
+     'hurd');
+
+# Yes, this includes combinations that are rather unlikely to ever exist, like
+# hurd-sh3, but the chances of those showing up as errors are rather low and
+# this reduces the necessary updating.
+#
+# For right now, linux-* are non-standard architectures.  This probably isn't
+# strictly correct and will need to be revisited later.
 %non_standard_archs = map { $_ => 1 }
-    ('amd64', 'ppc64', 'sh', 'kfreebsd-i386', 'knetbsd-i386');
+    grep { !$known_archs{$_} }
+        (keys %all_cpus,
+         map { my $os = $_; map { "$os-$_" } keys %all_cpus } keys %all_oses);
 
 
 %known_sections = map { $_ => 1 }
@@ -31,8 +56,7 @@ use base qw(Exporter);
 %known_non_us_parts = map { $_ => 1 } ('non-free', 'contrib', 'main' );
 
 %known_archive_parts = map { $_ => 1 }
-    ('non-free', 'contrib', 'non-US', 'non-us',
-     'restricted', 'universe', 'multiverse');
+    ('non-free', 'contrib', 'non-US', 'non-us' );
 
 %known_prios = map { $_ => 1 }
     ('required', 'important', 'standard', 'optional', 'extra');
@@ -71,7 +95,7 @@ use base qw(Exporter);
 %known_obsolete_packages = map { $_ => 1 }
     ('libstdc++2.8', 'ncurses3.4', 'slang0.99.38', 'newt0.25', 'mesag2',
      'libjpegg6a', 'gmp2', 'libgtop0', 'libghttp0', 'libpgsql', 'tk4.2',
-     'tcl7.6', 'libpng0g', 'xbase');
+     'tcl7.6', 'libpng0g', 'xbase', 'xlibs-dev', 'debmake', 'gcc-2.95' );
 
 # Used only (at least lintian 1.23.1) for giving a warning about a
 # virtual-only dependency
@@ -103,6 +127,7 @@ use base qw(Exporter);
 %known_libstdcs = map { $_ => 1 }
     ('libstdc++2.9-glibc2.1', 'libstdc++2.10', 'libstdc++2.10-glibc2.2',
      'libstdc++3', 'libstdc++3.0', 'libstdc++4', 'libstdc++5',
+     'libstdc++6', 'lib64stdc++6',
     );
 
 %known_tcls = map { $_ => 1 }
@@ -120,4 +145,12 @@ use base qw(Exporter);
 %known_libpngs = map { $_ => 1 }
     ( 'libpng12-0', 'libpng2', 'libpng3', );
 
+%known_x_metapackages = map { $_ => 1 }
+    ( 'x-window-system', 'x-window-system-dev', 'x-window-system-core',
+      'xorg', 'xorg-dev', );
+
+# Supported documentation formats for doc-base files.
+%known_doc_base_formats = map { $_ => 1 }
+    ( 'html', 'text', 'pdf', 'postscript', 'info', 'dvi', 'debiandoc-sgml' );
+
 1;
